@@ -3,8 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
+use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
 use Music::Scales qw(get_scale_notes is_scale);
 use Music::Note;
@@ -66,7 +67,7 @@ sub transpose {
             push @transposed, $i == -1 ? undef : $self->_scale->[ $i + $offset ];
         }
     }
-    print "Transposed: @transposed\n" if $self->verbose;
+    print 'Transposed: ', ddc(\@transposed) if $self->verbose;
 
     return \@transposed;
 }
@@ -85,7 +86,7 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
